@@ -13,7 +13,9 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 #pragma once
+#include "dpiManagerV2.h"
 #include "Notepad_plus_msgs.h"
 #include "Window.h"
 
@@ -69,10 +71,26 @@ public :
 		::SendDlgItemMessage(_hSelf, checkControlID, BM_SETCHECK, checkOrNot ? BST_CHECKED : BST_UNCHECKED, 0);
 	}
 
+	void setDpi() {
+		_dpiManager.setDpi(_hSelf);
+	}
+
+	void setPositionDpi(LPARAM lParam, UINT flags = SWP_NOSIZE | SWP_NOZORDER | SWP_NOACTIVATE) {
+		DPIManagerV2::setPositionDpi(lParam, _hSelf, flags);
+	}
+
+	void sendDpiMsgToChildCtrls(WPARAM wParam = 0, LPARAM lParam = 0) {
+		DPIManagerV2::sendMessageToChildControls(_hSelf, WM_DPICHANGED, wParam, lParam);
+	}
+
 	void destroy() override;
 
+	DPIManagerV2& dpiManager() { return _dpiManager; }
+
 protected:
 	RECT _rc{};
+	DPIManagerV2 _dpiManager;
+
 	static intptr_t CALLBACK dlgProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam);
 	virtual intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) = 0;
 
