@@ -87,7 +87,7 @@ LRESULT TreeView::runProc(HWND hwnd, UINT Message, WPARAM wParam, LPARAM lParam)
 				nmtv.hdr.code = TVN_ITEMEXPANDED;
 				nmtv.hdr.hwndFrom = _hSelf;
 				nmtv.hdr.idFrom = 0;
-				nmtv.action = wParam & TVE_COLLAPSE ? TVE_COLLAPSE : TVE_EXPAND;
+				nmtv.action = (wParam & TVE_COLLAPSE) ? TVE_COLLAPSE : TVE_EXPAND;
 				nmtv.itemNew.hItem = tvItem.hItem;
 				::SendMessage(_hParent, WM_NOTIFY, nmtv.hdr.idFrom, reinterpret_cast<LPARAM>(&nmtv));
 			}
